diff --git a/Applications/FileIO/CsvInterface.cpp b/Applications/FileIO/CsvInterface.cpp
index 19636a82ee6f36f3e69cc6578ddc65163a3712ff..aa61387717c68ad10b5bfc605b2a7ab8755e2e56 100644
--- a/Applications/FileIO/CsvInterface.cpp
+++ b/Applications/FileIO/CsvInterface.cpp
@@ -93,9 +93,9 @@ int CsvInterface::readPoints(std::string const& fname, char delim,
             continue;
         }
         it = fields.begin();
-        std::array<double, 3> point{};
         try
         {
+            std::array<double, 3> point{};
             point[0] = std::stod(*it);
             point[1] = std::stod(*(++it));
             point[2] = std::stod(*(++it));
diff --git a/Applications/FileIO/Gmsh/GMSHInterface.cpp b/Applications/FileIO/Gmsh/GMSHInterface.cpp
index 97740c90feee9bac87c30b43569f22bdbf04b9c0..2a829a914cae4bdaf8b8ca7669b8f68166374644 100644
--- a/Applications/FileIO/Gmsh/GMSHInterface.cpp
+++ b/Applications/FileIO/Gmsh/GMSHInterface.cpp
@@ -18,6 +18,7 @@
 #include "Applications/FileIO/Gmsh/GMSHMeshDensityStrategy.h"
 #include "Applications/FileIO/Gmsh/GMSHPoint.h"
 #include "Applications/FileIO/Gmsh/GMSHPolygonTree.h"
+#include "BaseLib/Algorithm.h"
 #include "BaseLib/FileTools.h"
 #include "BaseLib/Logging.h"
 #include "GeoLib/AnalyticalGeometry.h"
@@ -75,11 +76,8 @@ GMSHInterface::GMSHInterface(
 
 GMSHInterface::~GMSHInterface()
 {
-    for (auto* gmsh_pnt : _gmsh_pnts)
-    {
-        delete gmsh_pnt;
-    }
-    for (auto* polygon_tree : _polygon_tree_list)
+    BaseLib::cleanupVectorElements(_gmsh_pnts);
+    for (auto const* polygon_tree : _polygon_tree_list)
     {
         delete polygon_tree;
     }
diff --git a/Applications/FileIO/Gmsh/GMSHPolygonTree.cpp b/Applications/FileIO/Gmsh/GMSHPolygonTree.cpp
index b308c1478ba1789215dff7d173b53277ceb2963f..e22986a59b8f9aa03eb800c771e3809659f2d15f 100644
--- a/Applications/FileIO/Gmsh/GMSHPolygonTree.cpp
+++ b/Applications/FileIO/Gmsh/GMSHPolygonTree.cpp
@@ -12,6 +12,7 @@
 
 #include <sstream>
 
+#include "BaseLib/Algorithm.h"
 #include "GMSHAdaptiveMeshDensity.h"
 #include "GMSHFixedMeshDensity.h"
 #include "GeoLib/AnalyticalGeometry.h"
@@ -44,10 +45,7 @@ GMSHPolygonTree::~GMSHPolygonTree()
     // responsible to cleanup up
     if (isRoot())
     {  // root
-        for (auto* polyline : _plys)
-        {
-            delete polyline;
-        }
+        BaseLib::cleanupVectorElements(_plys);
     }
 }
 
diff --git a/Applications/FileIO/Legacy/OGSIOVer4.cpp b/Applications/FileIO/Legacy/OGSIOVer4.cpp
index b23d1f9322ec597f060035278beffa8e7110dc94..cfd58b39a8d83816a0c7f20185095b66f35441ef 100644
--- a/Applications/FileIO/Legacy/OGSIOVer4.cpp
+++ b/Applications/FileIO/Legacy/OGSIOVer4.cpp
@@ -818,7 +818,7 @@ void writeAllDataToGLIFileV4(const std::string& fname,
 
     // writing surfaces as TIN files
     std::size_t sfcs_cnt(0);
-    for (auto& geo_name : geo_names)
+    for (auto const& geo_name : geo_names)
     {
         const GeoLib::SurfaceVec* sfcs_vec(geo.getSurfaceVecObj(geo_name));
         if (sfcs_vec)
diff --git a/BaseLib/FileTools.cpp b/BaseLib/FileTools.cpp
index 13eaefe5099ed749b7f4e78c4da46fed15e8753b..39e3f293c020c78ce85f612af3db63af76aa9812 100644
--- a/BaseLib/FileTools.cpp
+++ b/BaseLib/FileTools.cpp
@@ -101,8 +101,7 @@ bool substituteKeyword(std::string& result, std::string& parenthesized_string,
     if (b == 'e' || b == 'E' || b == 'f' || b == 'F' || b == 'g' || b == 'G')
     {
         type_specification[std::type_index(typeid(double))] = b;
-        precision_specification = precision_specification.substr(
-            0, precision_specification.length() - 1);
+        precision_specification.pop_back();
     }
 
     std::string const generated_fmt_string =
diff --git a/ChemistryLib/PhreeqcIOData/UserPunch.cpp b/ChemistryLib/PhreeqcIOData/UserPunch.cpp
index 2c78b81eb6f47155872f5e2e0c76ae3db61015cd..e36ac9842dcb32fbe374f9687c5b867decccd87e 100644
--- a/ChemistryLib/PhreeqcIOData/UserPunch.cpp
+++ b/ChemistryLib/PhreeqcIOData/UserPunch.cpp
@@ -30,7 +30,7 @@ std::ostream& operator<<(std::ostream& os, UserPunch const& user_punch)
        << "\n";
     os << "-headings ";
     auto const& secondary_variables = user_punch.secondary_variables;
-    for (auto& secondary_variable : secondary_variables)
+    for (auto const& secondary_variable : secondary_variables)
     {
         os << secondary_variable.name << " ";
     }
diff --git a/ChemistryLib/PhreeqcKernelData/EquilibriumReactants.cpp b/ChemistryLib/PhreeqcKernelData/EquilibriumReactants.cpp
index dfbb13cdc2ca42eb88ab83229538115b40953c2c..05fe534638570c6cb72ea142037022df0e7b8cbe 100644
--- a/ChemistryLib/PhreeqcKernelData/EquilibriumReactants.cpp
+++ b/ChemistryLib/PhreeqcKernelData/EquilibriumReactants.cpp
@@ -27,7 +27,7 @@ PhaseComponent::PhaseComponent(std::string&& name_,
 EquilibriumReactants::EquilibriumReactants(
     std::vector<PhaseComponent> const& phase_components)
 {
-    for (auto& phase_component : phase_components)
+    for (auto const& phase_component : phase_components)
     {
         auto& name = phase_component.getName();
         pp_assemblage_comps[name] = *phase_component.castToBaseClass();
diff --git a/Documentation/ProjectFile/properties/property/SigmoidFunction/c_SigmoidFunction.md b/Documentation/ProjectFile/properties/property/SigmoidFunction/c_SigmoidFunction.md
deleted file mode 100644
index 40294743ab338b280ca6bd2010c10a80dcbcc5ba..0000000000000000000000000000000000000000
--- a/Documentation/ProjectFile/properties/property/SigmoidFunction/c_SigmoidFunction.md
+++ /dev/null
@@ -1 +0,0 @@
-\copydoc MaterialPropertyLib::SigmoidFunction
diff --git a/Documentation/ProjectFile/properties/property/SigmoidFunction/t_characteristic_temperature.md b/Documentation/ProjectFile/properties/property/SigmoidFunction/t_characteristic_temperature.md
deleted file mode 100644
index e7566dd5a3fd8a870258d71a11f0888758051a83..0000000000000000000000000000000000000000
--- a/Documentation/ProjectFile/properties/property/SigmoidFunction/t_characteristic_temperature.md
+++ /dev/null
@@ -1 +0,0 @@
-\copydoc MaterialPropertyLib::SigmoidFunction::T_c_
diff --git a/Documentation/ProjectFile/properties/property/SigmoidFunction/t_steepness.md b/Documentation/ProjectFile/properties/property/SigmoidFunction/t_steepness.md
deleted file mode 100644
index 1c10c3f25097f5fde7a1f95ec4a2cceab8820925..0000000000000000000000000000000000000000
--- a/Documentation/ProjectFile/properties/property/SigmoidFunction/t_steepness.md
+++ /dev/null
@@ -1 +0,0 @@
-\copydoc MaterialPropertyLib::SigmoidFunction::k_
diff --git a/GeoLib/Grid.h b/GeoLib/Grid.h
index 06edee0c949ba559c879bbc9979b1fd86fa5dd3a..e811d6d3ec69dfd08e082b6f976beb9d39314843 100644
--- a/GeoLib/Grid.h
+++ b/GeoLib/Grid.h
@@ -52,6 +52,9 @@ public:
     Grid(InputIterator first, InputIterator last,
          std::size_t max_num_per_grid_cell = 512);
 
+    Grid(Grid const&) = delete;
+    Grid& operator=(Grid const&) = delete;
+
     /**
      * This is the destructor of the class. It deletes the internal data
      * structures *not* including the pointers to the points.
diff --git a/GeoLib/PointVec.cpp b/GeoLib/PointVec.cpp
index b83f7be9eee452a432eb275f040232afe59caab1..129696fbd4c24c7a5754a072e574c953485d879a 100644
--- a/GeoLib/PointVec.cpp
+++ b/GeoLib/PointVec.cpp
@@ -206,7 +206,7 @@ void PointVec::correctNameIDMapping()
 {
     // create mapping id -> name using the std::vector id_names
     std::vector<std::string> id_names(_pnt_id_map.size(), std::string(""));
-    for (auto& id_name_pair : _name_id_map)
+    for (auto const& id_name_pair : _name_id_map)
     {
         id_names[id_name_pair.second] = id_name_pair.first;
     }
diff --git a/GeoLib/QuadTree.h b/GeoLib/QuadTree.h
index f179cb0097a7f2f927b7c048cfe6aac2e51262bc..d12915f91f1d53c9ac78c1cfbd518167b607d79d 100644
--- a/GeoLib/QuadTree.h
+++ b/GeoLib/QuadTree.h
@@ -84,7 +84,7 @@ public:
      */
     ~QuadTree()
     {
-        for (auto& child : _children)
+        for (auto const& child : _children)
         {
             delete child;
         }
diff --git a/MaterialLib/Adsorption/ReactionCaOH2.cpp b/MaterialLib/Adsorption/ReactionCaOH2.cpp
index 83c2bb1a48af230f1107c5c8be7fde40e0136eaa..8f120d27b2401f7236f5b27324e4e35f321e5f91 100644
--- a/MaterialLib/Adsorption/ReactionCaOH2.cpp
+++ b/MaterialLib/Adsorption/ReactionCaOH2.cpp
@@ -53,10 +53,10 @@ double ReactionCaOH2::getReactionRate(double const solid_density)
     return _qR;
 }
 
-void ReactionCaOH2::updateParam(double T_solid,
-                                double p_gas,
-                                double x_react,
-                                double rho_s_initial)
+void ReactionCaOH2::updateParam(double const T_solid,
+                                double const p_gas,
+                                double const x_react,
+                                double const rho_s_initial)
 {
     _T_s = T_solid;
     _p_gas = p_gas / 1e5;  // convert Pa to bar
diff --git a/MaterialLib/Adsorption/ReactionCaOH2.h b/MaterialLib/Adsorption/ReactionCaOH2.h
index 8a5b653a3db5acb517a45860c86b5ea703194abe..032dc3e8831ca13a65347526f2369287bcfb66f7 100644
--- a/MaterialLib/Adsorption/ReactionCaOH2.h
+++ b/MaterialLib/Adsorption/ReactionCaOH2.h
@@ -43,10 +43,8 @@ public:
     // TODO merge with getReactionRate() above
     double getReactionRate(double const solid_density);
 
-    void updateParam(double T_solid,
-                      double _p_gas,
-                      double _x_react,
-                      double rho_s_initial);
+    void updateParam(double T_solid, double p_gas, double x_react,
+                     double rho_s_initial);
 
 private:
     void calculateQR();
diff --git a/MaterialLib/MPL/Properties/AverageMolarMass.cpp b/MaterialLib/MPL/Properties/AverageMolarMass.cpp
index 54923693c1f719c4efdeaeba4162cac2d13db1ae..d5f51a7362e3ed896750b8c73668ccf8dae449bd 100644
--- a/MaterialLib/MPL/Properties/AverageMolarMass.cpp
+++ b/MaterialLib/MPL/Properties/AverageMolarMass.cpp
@@ -83,12 +83,12 @@ PropertyDataType AverageMolarMass::value(
 }
 
 PropertyDataType AverageMolarMass::dValue(
-    VariableArray const& variable_array, Variable const primary_variable,
+    VariableArray const& variable_array, Variable const variable,
     ParameterLib::SpatialPosition const& pos, double const t,
     double const dt) const
 {
-    if ((primary_variable != Variable::phase_pressure) &&
-        (primary_variable != Variable::temperature))
+    if ((variable != Variable::phase_pressure) &&
+        (variable != Variable::temperature))
     {
         OGS_FATAL(
             "AverageMolarMass::dValue is implemented for derivatives with "
@@ -114,7 +114,7 @@ PropertyDataType AverageMolarMass::dValue(
     // for binary phases only.
     auto const dxnC = phase->property(PropertyType::mole_fraction)
                           .template dValue<Eigen::Vector2d>(
-                              variable_array, primary_variable, pos, t, dt)[0];
+                              variable_array, variable, pos, t, dt)[0];
 
     auto const M_0 = phase->component(0)
                          .property(PropertyType::molar_mass)
@@ -128,10 +128,9 @@ PropertyDataType AverageMolarMass::dValue(
 }  // namespace MaterialPropertyLib
 
 PropertyDataType AverageMolarMass::d2Value(
-    VariableArray const& /*variable_array*/,
-    Variable const /*primary_variable1*/, Variable const /*primary_variable2*/,
-    ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
-    double const /*dt*/) const
+    VariableArray const& /*variable_array*/, Variable const /*variable1*/,
+    Variable const /*variable2*/, ParameterLib::SpatialPosition const& /*pos*/,
+    double const /*t*/, double const /*dt*/) const
 {
     OGS_FATAL("AverageMolarMass::d2Value is not yet implemented.");
 
diff --git a/MaterialLib/MPL/Properties/AverageMolarMass.h b/MaterialLib/MPL/Properties/AverageMolarMass.h
index 72b2864c83f5578f1577e386581c39f47b6553f5..331d011174eed2ca254ff6aa78d2291eb4f330de 100644
--- a/MaterialLib/MPL/Properties/AverageMolarMass.h
+++ b/MaterialLib/MPL/Properties/AverageMolarMass.h
@@ -38,7 +38,7 @@ public:
                            double const /*t*/,
                            double const /*dt*/) const override;
     PropertyDataType dValue(VariableArray const& variable_array,
-                            Variable const primary_variable,
+                            Variable const variable,
                             ParameterLib::SpatialPosition const& /*pos*/,
                             double const /*t*/,
                             double const /*dt*/) const override;
diff --git a/MaterialLib/MPL/Properties/CapillaryPressureSaturation/CapillaryPressureRegularizedVanGenuchten.cpp b/MaterialLib/MPL/Properties/CapillaryPressureSaturation/CapillaryPressureRegularizedVanGenuchten.cpp
index 02069f2a1b105d159b0c80edb4aca45c9fbbaa96..88b1b66cddc2023e65be39928321bc3c079353da 100644
--- a/MaterialLib/MPL/Properties/CapillaryPressureSaturation/CapillaryPressureRegularizedVanGenuchten.cpp
+++ b/MaterialLib/MPL/Properties/CapillaryPressureSaturation/CapillaryPressureRegularizedVanGenuchten.cpp
@@ -68,11 +68,11 @@ PropertyDataType CapillaryPressureRegularizedVanGenuchten::value(
 }
 
 PropertyDataType CapillaryPressureRegularizedVanGenuchten::dValue(
-    VariableArray const& variable_array, Variable const primary_variable,
+    VariableArray const& variable_array, Variable const variable,
     ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
     double const /*dt*/) const
 {
-    if (primary_variable != Variable::liquid_saturation)
+    if (variable != Variable::liquid_saturation)
     {
         OGS_FATAL(
             "CapillaryPressureRegularizedVanGenuchten::dValue is implemented "
diff --git a/MaterialLib/MPL/Properties/CapillaryPressureSaturation/CapillaryPressureVanGenuchten.cpp b/MaterialLib/MPL/Properties/CapillaryPressureSaturation/CapillaryPressureVanGenuchten.cpp
index c44eb6e4d0caf0b482e418dea6461e1a94455297..44487d006744c56978742e8cf50df36aaf9c7f7d 100644
--- a/MaterialLib/MPL/Properties/CapillaryPressureSaturation/CapillaryPressureVanGenuchten.cpp
+++ b/MaterialLib/MPL/Properties/CapillaryPressureSaturation/CapillaryPressureVanGenuchten.cpp
@@ -107,11 +107,11 @@ PropertyDataType CapillaryPressureVanGenuchten::value(
 }
 
 PropertyDataType CapillaryPressureVanGenuchten::dValue(
-    VariableArray const& variable_array, Variable const primary_variable,
+    VariableArray const& variable_array, Variable const variable,
     ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
     double const /*dt*/) const
 {
-    if (primary_variable != Variable::liquid_saturation)
+    if (variable != Variable::liquid_saturation)
     {
         OGS_FATAL(
             "CapillaryPressureVanGenuchten::dValue is implemented for "
diff --git a/MaterialLib/MPL/Properties/CapillaryPressureSaturation/SaturationBrooksCorey.cpp b/MaterialLib/MPL/Properties/CapillaryPressureSaturation/SaturationBrooksCorey.cpp
index 36836d20b394b81a22d9151965a302b369cd9809..9780668df52526a871086299f73ce9d5c6af40a6 100644
--- a/MaterialLib/MPL/Properties/CapillaryPressureSaturation/SaturationBrooksCorey.cpp
+++ b/MaterialLib/MPL/Properties/CapillaryPressureSaturation/SaturationBrooksCorey.cpp
@@ -56,11 +56,11 @@ PropertyDataType SaturationBrooksCorey::value(
 }
 
 PropertyDataType SaturationBrooksCorey::dValue(
-    VariableArray const& variable_array, Variable const primary_variable,
+    VariableArray const& variable_array, Variable const variable,
     ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
     double const /*dt*/) const
 {
-    if (primary_variable != Variable::capillary_pressure)
+    if (variable != Variable::capillary_pressure)
     {
         OGS_FATAL(
             "SaturationBrooksCorey::dValue is implemented for derivatives with "
@@ -85,13 +85,12 @@ PropertyDataType SaturationBrooksCorey::dValue(
 }
 
 PropertyDataType SaturationBrooksCorey::d2Value(
-    VariableArray const& variable_array, Variable const primary_variable1,
-    Variable const primary_variable2,
-    ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
-    double const /*dt*/) const
+    VariableArray const& variable_array, Variable const variable1,
+    Variable const variable2, ParameterLib::SpatialPosition const& /*pos*/,
+    double const /*t*/, double const /*dt*/) const
 {
-    if ((primary_variable1 != Variable::capillary_pressure) &&
-        (primary_variable2 != Variable::capillary_pressure))
+    if ((variable1 != Variable::capillary_pressure) &&
+        (variable2 != Variable::capillary_pressure))
     {
         OGS_FATAL(
             "SaturationBrooksCorey::d2Value is implemented for derivatives "
diff --git a/MaterialLib/MPL/Properties/CapillaryPressureSaturation/SaturationExponential.cpp b/MaterialLib/MPL/Properties/CapillaryPressureSaturation/SaturationExponential.cpp
index af2a0869b29b441f388fcf39e4fd7c56d5d5c234..de7c3aa50b5879b195801b24afc0798dd1504fd9 100644
--- a/MaterialLib/MPL/Properties/CapillaryPressureSaturation/SaturationExponential.cpp
+++ b/MaterialLib/MPL/Properties/CapillaryPressureSaturation/SaturationExponential.cpp
@@ -58,11 +58,11 @@ PropertyDataType SaturationExponential::value(
 }
 
 PropertyDataType SaturationExponential::dValue(
-    VariableArray const& variable_array, Variable const primary_variable,
+    VariableArray const& variable_array, Variable const variable,
     ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
     double const /*dt*/) const
 {
-    if (primary_variable != Variable::capillary_pressure)
+    if (variable != Variable::capillary_pressure)
     {
         OGS_FATAL(
             "SaturationExponential::dValue is implemented for derivatives with "
@@ -83,10 +83,9 @@ PropertyDataType SaturationExponential::dValue(
 }
 
 PropertyDataType SaturationExponential::d2Value(
-    VariableArray const& /*variable_array*/,
-    Variable const /*primary_variable1*/, Variable const /*primary_variable2*/,
-    ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
-    double const /*dt*/) const
+    VariableArray const& /*variable_array*/, Variable const /*variable1*/,
+    Variable const /*variable2*/, ParameterLib::SpatialPosition const& /*pos*/,
+    double const /*t*/, double const /*dt*/) const
 {
     OGS_FATAL("SaturationExponential::d2Value() is not implemented.");
 }
diff --git a/MaterialLib/MPL/Properties/CapillaryPressureSaturation/SaturationExponential.h b/MaterialLib/MPL/Properties/CapillaryPressureSaturation/SaturationExponential.h
index f60d1624b91ff50066a8a90fca6fdb30a6f7a874..9cdde6acff5b20429334ef067f84b37db68ca9ed 100644
--- a/MaterialLib/MPL/Properties/CapillaryPressureSaturation/SaturationExponential.h
+++ b/MaterialLib/MPL/Properties/CapillaryPressureSaturation/SaturationExponential.h
@@ -68,13 +68,13 @@ public:
                            double const /*t*/,
                            double const /*dt*/) const override;
     PropertyDataType dValue(VariableArray const& variable_array,
-                            Variable const primary_variable,
+                            Variable const variable,
                             ParameterLib::SpatialPosition const& /*pos*/,
                             double const /*t*/,
                             double const /*dt*/) const override;
     PropertyDataType d2Value(VariableArray const& variable_array,
-                             Variable const /*primary_variable1*/,
-                             Variable const /*primary_variable2*/,
+                             Variable const /*variable1*/,
+                             Variable const /*variable2*/,
                              ParameterLib::SpatialPosition const& /*pos*/,
                              double const /*t*/,
                              double const /*dt*/) const override;
diff --git a/MaterialLib/MPL/Properties/CapillaryPressureSaturation/SaturationLiakopoulos.cpp b/MaterialLib/MPL/Properties/CapillaryPressureSaturation/SaturationLiakopoulos.cpp
index ae2017caa62abb306158c9a202b8a09148bba500..7536285d87df46962218206fa6eef3112f4ed0fc 100644
--- a/MaterialLib/MPL/Properties/CapillaryPressureSaturation/SaturationLiakopoulos.cpp
+++ b/MaterialLib/MPL/Properties/CapillaryPressureSaturation/SaturationLiakopoulos.cpp
@@ -37,11 +37,11 @@ PropertyDataType SaturationLiakopoulos::value(
 }
 
 PropertyDataType SaturationLiakopoulos::dValue(
-    VariableArray const& variable_array, Variable const primary_variable,
+    VariableArray const& variable_array, Variable const variable,
     ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
     double const /*dt*/) const
 {
-    if (primary_variable != Variable::capillary_pressure)
+    if (variable != Variable::capillary_pressure)
     {
         OGS_FATAL(
             "SaturationLiakopoulos::dValue is implemented for derivatives with "
@@ -60,13 +60,12 @@ PropertyDataType SaturationLiakopoulos::dValue(
 }
 
 PropertyDataType SaturationLiakopoulos::d2Value(
-    VariableArray const& variable_array, Variable const primary_variable1,
-    Variable const primary_variable2,
-    ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
-    double const /*dt*/) const
+    VariableArray const& variable_array, Variable const variable1,
+    Variable const variable2, ParameterLib::SpatialPosition const& /*pos*/,
+    double const /*t*/, double const /*dt*/) const
 {
-    if ((primary_variable1 != Variable::capillary_pressure) &&
-        (primary_variable2 != Variable::capillary_pressure))
+    if ((variable1 != Variable::capillary_pressure) &&
+        (variable2 != Variable::capillary_pressure))
     {
         OGS_FATAL(
             "SaturationLiakopoulos::d2Value is implemented for derivatives "
diff --git a/MaterialLib/MPL/Properties/CapillaryPressureSaturation/SaturationVanGenuchten.cpp b/MaterialLib/MPL/Properties/CapillaryPressureSaturation/SaturationVanGenuchten.cpp
index 472d3be853c047f2d2c00c889ace1b067a6c43df..2f53c7f119b7dac492b978d4761e75a16d0234b1 100644
--- a/MaterialLib/MPL/Properties/CapillaryPressureSaturation/SaturationVanGenuchten.cpp
+++ b/MaterialLib/MPL/Properties/CapillaryPressureSaturation/SaturationVanGenuchten.cpp
@@ -61,11 +61,11 @@ PropertyDataType SaturationVanGenuchten::value(
 }
 
 PropertyDataType SaturationVanGenuchten::dValue(
-    VariableArray const& variable_array, Variable const primary_variable,
+    VariableArray const& variable_array, Variable const variable,
     ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
     double const /*dt*/) const
 {
-    if (primary_variable != Variable::capillary_pressure)
+    if (variable != Variable::capillary_pressure)
     {
         OGS_FATAL(
             "SaturationVanGenuchten::dValue is implemented for derivatives "
@@ -98,15 +98,14 @@ PropertyDataType SaturationVanGenuchten::dValue(
 }
 
 PropertyDataType SaturationVanGenuchten::d2Value(
-    VariableArray const& variable_array, Variable const primary_variable1,
-    Variable const primary_variable2,
-    ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
-    double const /*dt*/) const
+    VariableArray const& variable_array, Variable const variable1,
+    Variable const variable2, ParameterLib::SpatialPosition const& /*pos*/,
+    double const /*t*/, double const /*dt*/) const
 {
-    (void)primary_variable1;
-    (void)primary_variable2;
-    assert((primary_variable1 == Variable::capillary_pressure) &&
-           (primary_variable2 == Variable::capillary_pressure) &&
+    (void)variable1;
+    (void)variable2;
+    assert((variable1 == Variable::capillary_pressure) &&
+           (variable2 == Variable::capillary_pressure) &&
            "SaturationVanGenuchten::d2Value is implemented for  derivatives "
            "with respect to capillary pressure only.");
 
diff --git a/MaterialLib/MPL/Properties/ClausiusClapeyron.cpp b/MaterialLib/MPL/Properties/ClausiusClapeyron.cpp
index c844d61ca68fc81f441e96063d42c1f2964a24a4..10172c0a62798d5b85f7c9d383775e7849413edf 100644
--- a/MaterialLib/MPL/Properties/ClausiusClapeyron.cpp
+++ b/MaterialLib/MPL/Properties/ClausiusClapeyron.cpp
@@ -88,7 +88,7 @@ PropertyDataType ClausiusClapeyron::value(
 }
 
 PropertyDataType ClausiusClapeyron::dValue(
-    VariableArray const& variable_array, Variable const primary_variable,
+    VariableArray const& variable_array, Variable const variable,
     ParameterLib::SpatialPosition const& pos, double const t,
     double const dt) const
 {
@@ -103,7 +103,7 @@ PropertyDataType ClausiusClapeyron::dValue(
     {
         return 0.;
     }
-    if (primary_variable == Variable::phase_pressure)
+    if (variable == Variable::phase_pressure)
     {
         return 0.;
     }
@@ -112,7 +112,7 @@ PropertyDataType ClausiusClapeyron::dValue(
     const double dh = variable_array.enthalpy_of_evaporation;
     const double p_vap = std::get<double>(value(variable_array, pos, t, dt));
 
-    if (primary_variable == Variable::temperature)
+    if (variable == Variable::temperature)
     {
         return p_vap * M * dh / (R * T * T);
     }
@@ -122,10 +122,9 @@ PropertyDataType ClausiusClapeyron::dValue(
 }
 
 PropertyDataType ClausiusClapeyron::d2Value(
-    VariableArray const& /*variable_array*/,
-    Variable const /*primary_variable1*/, Variable const /*primary_variable2*/,
-    ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
-    double const /*dt*/) const
+    VariableArray const& /*variable_array*/, Variable const /*variable1*/,
+    Variable const /*variable2*/, ParameterLib::SpatialPosition const& /*pos*/,
+    double const /*t*/, double const /*dt*/) const
 {
     OGS_FATAL("ClausiusClapeyron::d2Value is not implemented.");
 }
diff --git a/MaterialLib/MPL/Properties/ClausiusClapeyron.h b/MaterialLib/MPL/Properties/ClausiusClapeyron.h
index 455fcc6e50c9f62bef21be4142a741a1f88a1486..4c02b9a94d1b015ea9bf904591352a53e4e6dd40 100644
--- a/MaterialLib/MPL/Properties/ClausiusClapeyron.h
+++ b/MaterialLib/MPL/Properties/ClausiusClapeyron.h
@@ -44,13 +44,13 @@ public:
                            double const t,
                            double const dt) const override;
     PropertyDataType dValue(VariableArray const& variable_array,
-                            Variable const primary_variable,
+                            Variable const variable,
                             ParameterLib::SpatialPosition const& pos,
                             double const t,
                             double const dt) const override;
     PropertyDataType d2Value(VariableArray const& variable_array,
-                             Variable const primary_variable1,
-                             Variable const primary_variable2,
+                             Variable const variable1,
+                             Variable const variable2,
                              ParameterLib::SpatialPosition const& pos,
                              double const t,
                              double const dt) const override;
diff --git a/MaterialLib/MPL/Properties/CreateTemperatureDependentFraction.cpp b/MaterialLib/MPL/Properties/CreateTemperatureDependentFraction.cpp
index 00209dbc9ed153e9369fddd64dcd85a585f8cb23..2ef426b011bd2d1c3149eb0821b9df553ff236aa 100644
--- a/MaterialLib/MPL/Properties/CreateTemperatureDependentFraction.cpp
+++ b/MaterialLib/MPL/Properties/CreateTemperatureDependentFraction.cpp
@@ -22,8 +22,7 @@ createTemperatureDependentFraction(BaseLib::ConfigTree const& config)
     //! \ogs_file_param{properties__property__name}
     auto property_name = config.peekConfigParameter<std::string>("name");
 
-    DBUG("Create temperature dependent fraction property {:s}.",
-         property_name);
+    DBUG("Create temperature dependent fraction property {:s}.", property_name);
 
     auto const k =
         //! \ogs_file_param{properties__property__TemperatureDependentFraction__steepness}
@@ -33,8 +32,7 @@ createTemperatureDependentFraction(BaseLib::ConfigTree const& config)
         //! \ogs_file_param{properties__property__TemperatureDependentFraction__characteristic_temperature}
         config.getConfigParameter<double>("characteristic_temperature");
 
-    return std::make_unique<
-        MaterialPropertyLib::TemperatureDependentFraction>(
+    return std::make_unique<MaterialPropertyLib::TemperatureDependentFraction>(
         std::move(property_name), k, T_c);
 }
 }  // namespace MaterialPropertyLib
diff --git a/MaterialLib/MPL/Properties/CreateVolumeFractionAverage.cpp b/MaterialLib/MPL/Properties/CreateVolumeFractionAverage.cpp
index 2944104327189957138fdadeac382ad79d87c77f..92c0b354cf9ca0d302c4a7a6760784e56393518e 100644
--- a/MaterialLib/MPL/Properties/CreateVolumeFractionAverage.cpp
+++ b/MaterialLib/MPL/Properties/CreateVolumeFractionAverage.cpp
@@ -12,8 +12,8 @@
 
 namespace MaterialPropertyLib
 {
-std::unique_ptr<VolumeFractionAverage>
-createVolumeFractionAverage(BaseLib::ConfigTree const& config)
+std::unique_ptr<VolumeFractionAverage> createVolumeFractionAverage(
+    BaseLib::ConfigTree const& config)
 {
     //! \ogs_file_param{properties__property__type}
     config.checkConfigParameter("type", "VolumeFractionAverage");
@@ -27,8 +27,7 @@ createVolumeFractionAverage(BaseLib::ConfigTree const& config)
 
     // no input parameters required here (taken from phase properties)
 
-    return std::make_unique<
-        MaterialPropertyLib::VolumeFractionAverage>(
+    return std::make_unique<MaterialPropertyLib::VolumeFractionAverage>(
         std::move(property_name));
 }
 }  // namespace MaterialPropertyLib
diff --git a/MaterialLib/MPL/Properties/Curve.cpp b/MaterialLib/MPL/Properties/Curve.cpp
index eb7f75a0f80ab5753e3f77a525dbc5481b30990c..bc291a2ce0fe658310d38900cfe9a669b7995ad6 100644
--- a/MaterialLib/MPL/Properties/Curve.cpp
+++ b/MaterialLib/MPL/Properties/Curve.cpp
@@ -29,11 +29,11 @@ PropertyDataType Curve::value(VariableArray const& variable_array,
 }
 
 PropertyDataType Curve::dValue(VariableArray const& variable_array,
-                               Variable const primary_variable,
+                               Variable const variable,
                                ParameterLib::SpatialPosition const& /*pos*/,
                                double const /*t*/, double const /*dt*/) const
 {
-    if (primary_variable != independent_variable_)
+    if (variable != independent_variable_)
     {
         return 0.0;
     }
diff --git a/MaterialLib/MPL/Properties/Curve.h b/MaterialLib/MPL/Properties/Curve.h
index e29f452c65e289cb1fbdec2716f03c653a8b1e0f..f212e5e2e4d33d727bb88ea1227ceb0ed213a4f8 100644
--- a/MaterialLib/MPL/Properties/Curve.h
+++ b/MaterialLib/MPL/Properties/Curve.h
@@ -37,7 +37,7 @@ public:
     /// This method will compute the derivative of a property with respect to
     /// the given primary variable.
     PropertyDataType dValue(VariableArray const& variable_array,
-                            Variable const primary_variable,
+                            Variable const variable,
                             ParameterLib::SpatialPosition const& /*pos*/,
                             double const /*t*/,
                             double const /*dt*/) const override;
diff --git a/MaterialLib/MPL/Properties/Density/WaterVapourDensity.cpp b/MaterialLib/MPL/Properties/Density/WaterVapourDensity.cpp
index a294d8a6051353896de2ffe486b14fec0d3ce08d..f68b614283455cda9f8eae008ce0bba2b422a50d 100644
--- a/MaterialLib/MPL/Properties/Density/WaterVapourDensity.cpp
+++ b/MaterialLib/MPL/Properties/Density/WaterVapourDensity.cpp
@@ -52,7 +52,7 @@ PropertyDataType WaterVapourDensity::value(
 }
 
 PropertyDataType WaterVapourDensity::dValue(
-    VariableArray const& variable_array, Variable const primary_variable,
+    VariableArray const& variable_array, Variable const variable,
     ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
     double const /*dt*/) const
 {
@@ -60,7 +60,7 @@ PropertyDataType WaterVapourDensity::dValue(
     double const T = variable_array.temperature;
     double const water_density = variable_array.density;
 
-    if (primary_variable == Variable::temperature)
+    if (variable == Variable::temperature)
     {
         double const h = humidity(T, p, water_density);
         double const rho_v = h * saturatedVaporDensity(T);
@@ -72,7 +72,7 @@ PropertyDataType WaterVapourDensity::dValue(
                                          SpecificGasConstant::WaterVapour);
     }
 
-    if (primary_variable == Variable::phase_pressure)
+    if (variable == Variable::phase_pressure)
     {
         double const factor =
             1.0 /
diff --git a/MaterialLib/MPL/Properties/Density/WaterVapourDensity.h b/MaterialLib/MPL/Properties/Density/WaterVapourDensity.h
index 098b0fc510a81db6cecf3b2dc060477039c2a36c..967342f481c7a0b5a1e20dcae8b5d62cb1695675 100644
--- a/MaterialLib/MPL/Properties/Density/WaterVapourDensity.h
+++ b/MaterialLib/MPL/Properties/Density/WaterVapourDensity.h
@@ -71,7 +71,7 @@ public:
     /// \return The derivative of  water vapour density with respect to
     /// temperature or phase (water) pressure.
     PropertyDataType dValue(VariableArray const& variable_array,
-                            Variable const primary_variable,
+                            Variable const variable,
                             ParameterLib::SpatialPosition const& pos,
                             double const t, double const dt) const override;
 };
diff --git a/MaterialLib/MPL/Properties/EmbeddedFracturePermeability.cpp b/MaterialLib/MPL/Properties/EmbeddedFracturePermeability.cpp
index 6998b4e8e7ac7cbe44dacb9f34af90e474adb3d7..45e2f537b20055e53134fb1c34a56eca948dbb03 100644
--- a/MaterialLib/MPL/Properties/EmbeddedFracturePermeability.cpp
+++ b/MaterialLib/MPL/Properties/EmbeddedFracturePermeability.cpp
@@ -92,11 +92,11 @@ PropertyDataType EmbeddedFracturePermeability<DisplacementDim>::value(
 
 template <int DisplacementDim>
 PropertyDataType EmbeddedFracturePermeability<DisplacementDim>::dValue(
-    VariableArray const& variable_array, Variable const primary_variable,
+    VariableArray const& variable_array, Variable const variable,
     ParameterLib::SpatialPosition const& pos, double const t,
     double const /*dt*/) const
 {
-    if (primary_variable != Variable::mechanical_strain)
+    if (variable != Variable::mechanical_strain)
     {
         OGS_FATAL(
             "EmbeddedFracturePermeability::dValue is implemented for "
diff --git a/MaterialLib/MPL/Properties/EmbeddedFracturePermeability.h b/MaterialLib/MPL/Properties/EmbeddedFracturePermeability.h
index 8f9a10ded24035b683cf560ac4d42185b330a0e5..6c41e86f2ecb636ab7366ba09a7d33c3769c928b 100644
--- a/MaterialLib/MPL/Properties/EmbeddedFracturePermeability.h
+++ b/MaterialLib/MPL/Properties/EmbeddedFracturePermeability.h
@@ -84,7 +84,7 @@ public:
                            ParameterLib::SpatialPosition const& pos,
                            double const t, double const dt) const override;
     PropertyDataType dValue(VariableArray const& variable_array,
-                            Variable const primary_variable,
+                            Variable const variable,
                             ParameterLib::SpatialPosition const& pos,
                             double const t, double const dt) const override;
 };
diff --git a/MaterialLib/MPL/Properties/Enthalpy/LinearWaterVapourLatentHeat.cpp b/MaterialLib/MPL/Properties/Enthalpy/LinearWaterVapourLatentHeat.cpp
index 5afd5d2ee55b7443dcd25ea4a16b9d3ce575ea26..146217ca77bb1a5d347e28526c279fc2cecdb677 100644
--- a/MaterialLib/MPL/Properties/Enthalpy/LinearWaterVapourLatentHeat.cpp
+++ b/MaterialLib/MPL/Properties/Enthalpy/LinearWaterVapourLatentHeat.cpp
@@ -31,11 +31,11 @@ PropertyDataType LinearWaterVapourLatentHeat::value(
 }
 
 PropertyDataType LinearWaterVapourLatentHeat::dValue(
-    VariableArray const& /*variable_array*/, Variable const primary_variable,
+    VariableArray const& /*variable_array*/, Variable const variable,
     ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
     double const /*dt*/) const
 {
-    if (primary_variable == Variable::temperature)
+    if (variable == Variable::temperature)
     {
         return -2369.2;
     }
diff --git a/MaterialLib/MPL/Properties/Enthalpy/LinearWaterVapourLatentHeat.h b/MaterialLib/MPL/Properties/Enthalpy/LinearWaterVapourLatentHeat.h
index d685fe1c61145fd218e615c25252bc62556d17d9..975cd0591e61bbfc82f2ba021f3c0d88bacb64aa 100644
--- a/MaterialLib/MPL/Properties/Enthalpy/LinearWaterVapourLatentHeat.h
+++ b/MaterialLib/MPL/Properties/Enthalpy/LinearWaterVapourLatentHeat.h
@@ -57,7 +57,7 @@ public:
                            double const dt) const override;
 
     PropertyDataType dValue(VariableArray const& variable_array,
-                            Variable const primary_variable,
+                            Variable const variable,
                             ParameterLib::SpatialPosition const& pos,
                             double const t, double const dt) const override;
 };
diff --git a/MaterialLib/MPL/Properties/Enthalpy/WaterVapourLatentHeatWithCriticalTemperature.cpp b/MaterialLib/MPL/Properties/Enthalpy/WaterVapourLatentHeatWithCriticalTemperature.cpp
index 81a1b6546404dc5d5a457dcdb144faaea4b0fd9f..449796bf91b30649b41678ae6c26a6130dd5a5d5 100644
--- a/MaterialLib/MPL/Properties/Enthalpy/WaterVapourLatentHeatWithCriticalTemperature.cpp
+++ b/MaterialLib/MPL/Properties/Enthalpy/WaterVapourLatentHeatWithCriticalTemperature.cpp
@@ -71,11 +71,11 @@ PropertyDataType WaterVapourLatentHeatWithCriticalTemperature::value(
 }
 
 PropertyDataType WaterVapourLatentHeatWithCriticalTemperature::dValue(
-    VariableArray const& variable_array, Variable const primary_variable,
+    VariableArray const& variable_array, Variable const variable,
     ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
     double const /*dt*/) const
 {
-    if (primary_variable != Variable::temperature)
+    if (variable != Variable::temperature)
     {
         OGS_FATAL(
             "WaterVapourLatentHeatWithCriticalTemperature::dValue is "
diff --git a/MaterialLib/MPL/Properties/Enthalpy/WaterVapourLatentHeatWithCriticalTemperature.h b/MaterialLib/MPL/Properties/Enthalpy/WaterVapourLatentHeatWithCriticalTemperature.h
index 5c0d02bb6e993567d23f0dda22a245f3e5646eb0..87a8f6c2ce3a44a588f40a86873d0d55ac01b4a0 100644
--- a/MaterialLib/MPL/Properties/Enthalpy/WaterVapourLatentHeatWithCriticalTemperature.h
+++ b/MaterialLib/MPL/Properties/Enthalpy/WaterVapourLatentHeatWithCriticalTemperature.h
@@ -82,7 +82,7 @@ public:
                            double const dt) const override;
 
     PropertyDataType dValue(VariableArray const& variable_array,
-                            Variable const primary_variable,
+                            Variable const variable,
                             ParameterLib::SpatialPosition const& pos,
                             double const t, double const dt) const override;
 };
diff --git a/MaterialLib/MPL/Properties/Exponential.cpp b/MaterialLib/MPL/Properties/Exponential.cpp
index 8e924c8ae5a00e979aab91ff8eb1f083a7c19a7c..40ddf9e4d899af985e78830a3e8d329044884e08 100644
--- a/MaterialLib/MPL/Properties/Exponential.cpp
+++ b/MaterialLib/MPL/Properties/Exponential.cpp
@@ -39,11 +39,11 @@ PropertyDataType Exponential::value(
 }
 
 PropertyDataType Exponential::dValue(
-    VariableArray const& variable_array, Variable const primary_variable,
+    VariableArray const& variable_array, Variable const variable,
     ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
     double const /*dt*/) const
 {
-    if (exponent_data_.type != primary_variable)
+    if (exponent_data_.type != variable)
     {
         return 0.;
     }
diff --git a/MaterialLib/MPL/Properties/Exponential.h b/MaterialLib/MPL/Properties/Exponential.h
index 252bef62e55e745b8091934b0c78e494d0877bdf..65757129e294ae128dfb7acd4fba3fd596bfc588 100644
--- a/MaterialLib/MPL/Properties/Exponential.h
+++ b/MaterialLib/MPL/Properties/Exponential.h
@@ -55,7 +55,7 @@ public:
     /// This method will compute the derivative of a property with respect
     /// to the given primary variable.
     PropertyDataType dValue(VariableArray const& variable_array,
-                            Variable const primary_variable,
+                            Variable const variable,
                             ParameterLib::SpatialPosition const& /*pos*/,
                             double const /*t*/,
                             double const /*dt*/) const override;
diff --git a/MaterialLib/MPL/Properties/Function.cpp b/MaterialLib/MPL/Properties/Function.cpp
index f4faaa95dcbf5f59bd6626ba303cc205ffd073c3..97e0ae21a857fb26fc5dfa370c787d37f84ea235 100644
--- a/MaterialLib/MPL/Properties/Function.cpp
+++ b/MaterialLib/MPL/Properties/Function.cpp
@@ -191,21 +191,21 @@ PropertyDataType Function::value(VariableArray const& variable_array,
 }
 
 PropertyDataType Function::dValue(VariableArray const& variable_array,
-                                  Variable const primary_variable,
+                                  Variable const variable,
                                   ParameterLib::SpatialPosition const& /*pos*/,
                                   double const /*t*/, double const /*dt*/) const
 {
     auto const it = std::find_if(begin(dvalue_expressions_),
                                  end(dvalue_expressions_),
-                                 [&primary_variable](auto const& v)
-                                 { return v.first == primary_variable; });
+                                 [&variable](auto const& v)
+                                 { return v.first == variable; });
 
     if (it == end(dvalue_expressions_))
     {
         OGS_FATAL(
             "Requested derivative with respect to the variable {:s} not "
             "provided for Function-type property {:s}.",
-            variable_enum_to_string[static_cast<int>(primary_variable)], name_);
+            variable_enum_to_string[static_cast<int>(variable)], name_);
     }
 
     return evaluateExpressions(symbol_values_, variable_array, it->second);
diff --git a/MaterialLib/MPL/Properties/Function.h b/MaterialLib/MPL/Properties/Function.h
index 4c531baeb7d151af0c323016472e2e94dfed641d..bcd0f0d5c1b9f0abf78a7e3e3529f57cd0d7b0dc 100644
--- a/MaterialLib/MPL/Properties/Function.h
+++ b/MaterialLib/MPL/Properties/Function.h
@@ -38,7 +38,7 @@ public:
                            double const dt) const override;
 
     PropertyDataType dValue(VariableArray const& variable_array,
-                            Variable const primary_variable,
+                            Variable const variable,
                             ParameterLib::SpatialPosition const& pos,
                             double const t,
                             double const dt) const override;
diff --git a/MaterialLib/MPL/Properties/IdealGasLaw.cpp b/MaterialLib/MPL/Properties/IdealGasLaw.cpp
index bf824a08070a2c150152a77981d3d6340495b07a..d29340d27cdfef58dbfc1af3149b77181920f6d3 100644
--- a/MaterialLib/MPL/Properties/IdealGasLaw.cpp
+++ b/MaterialLib/MPL/Properties/IdealGasLaw.cpp
@@ -41,7 +41,7 @@ PropertyDataType IdealGasLaw::value(
 }
 
 PropertyDataType IdealGasLaw::dValue(
-    VariableArray const& variable_array, Variable const primary_variable,
+    VariableArray const& variable_array, Variable const variable,
     ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
     double const /*dt*/) const
 {
@@ -51,14 +51,14 @@ PropertyDataType IdealGasLaw::dValue(
     const double molar_mass = variable_array.molar_mass;
     // todo: add molar mass derivatives
 
-    if (primary_variable == Variable::temperature)
+    if (variable == Variable::temperature)
     {
         // extend to take temperature-dependent molar mass into account
         return -pressure * molar_mass / gas_constant / temperature /
                temperature;
     }
 
-    if (primary_variable == Variable::phase_pressure)
+    if (variable == Variable::phase_pressure)
     {
         // extend to take pressure-dependent molar mass into account
         return molar_mass / gas_constant / temperature;
@@ -72,10 +72,9 @@ PropertyDataType IdealGasLaw::dValue(
 }
 
 PropertyDataType IdealGasLaw::d2Value(
-    VariableArray const& variable_array, Variable const primary_variable1,
-    Variable const primary_variable2,
-    ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
-    double const /*dt*/) const
+    VariableArray const& variable_array, Variable const variable1,
+    Variable const variable2, ParameterLib::SpatialPosition const& /*pos*/,
+    double const /*t*/, double const /*dt*/) const
 {
     const double gas_constant = MaterialLib::PhysicalConstant::IdealGasConstant;
     const double pressure = variable_array.phase_pressure;
@@ -83,25 +82,25 @@ PropertyDataType IdealGasLaw::d2Value(
     const double molar_mass = variable_array.molar_mass;
     // todo: add molar mass derivatives
 
-    if ((primary_variable1 == Variable::phase_pressure) &&
-        (primary_variable2 == Variable::phase_pressure))
+    if ((variable1 == Variable::phase_pressure) &&
+        (variable2 == Variable::phase_pressure))
     {
         // d2rho_dp2
         // extend to take pressure-dependent molar mass into account
         return 0.;
     }
-    if ((primary_variable1 == Variable::temperature) &&
-        (primary_variable2 == Variable::temperature))
+    if ((variable1 == Variable::temperature) &&
+        (variable2 == Variable::temperature))
     {
         // d2rho_dT2
         // extend to take temperature-dependent molar mass into account
         return 2. * molar_mass * pressure / gas_constant / temperature /
                temperature / temperature;
     }
-    if (((primary_variable1 == Variable::phase_pressure) &&
-         (primary_variable2 == Variable::temperature)) ||
-        ((primary_variable1 == Variable::temperature) &&
-         (primary_variable2 == Variable::phase_pressure)))
+    if (((variable1 == Variable::phase_pressure) &&
+         (variable2 == Variable::temperature)) ||
+        ((variable1 == Variable::temperature) &&
+         (variable2 == Variable::phase_pressure)))
     {
         // d2rho_dpdT or d2rho_dTdp
         // extend to take pressure-temperature-dependent molar mass into account
diff --git a/MaterialLib/MPL/Properties/IdealGasLawBinaryMixture.cpp b/MaterialLib/MPL/Properties/IdealGasLawBinaryMixture.cpp
index 2894aa48312aa28b6da20b5f31ca96cb2ff942ee..81d2ef38d64aed515b6a2c80f3cf15fcc7e67651 100644
--- a/MaterialLib/MPL/Properties/IdealGasLawBinaryMixture.cpp
+++ b/MaterialLib/MPL/Properties/IdealGasLawBinaryMixture.cpp
@@ -67,10 +67,9 @@ PropertyDataType IdealGasLawBinaryMixture::dValue(
 }
 
 PropertyDataType IdealGasLawBinaryMixture::d2Value(
-    VariableArray const& /*variable_array*/,
-    Variable const /*primary_variable1*/, Variable const /*primary_variable2*/,
-    ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
-    double const /*dt*/) const
+    VariableArray const& /*variable_array*/, Variable const /*variable1*/,
+    Variable const /*variable2*/, ParameterLib::SpatialPosition const& /*pos*/,
+    double const /*t*/, double const /*dt*/) const
 {
     OGS_FATAL("IdealGasLawBinaryMixture::d2Value is not implemented.");
 
diff --git a/MaterialLib/MPL/Properties/Linear.cpp b/MaterialLib/MPL/Properties/Linear.cpp
index df3d87d09d53eb33ac6febc870d8fe23a9bd9b18..6a39545a37cdc6e24b8c43c4b451f8c7dea823af 100644
--- a/MaterialLib/MPL/Properties/Linear.cpp
+++ b/MaterialLib/MPL/Properties/Linear.cpp
@@ -46,15 +46,14 @@ PropertyDataType Linear::value(VariableArray const& variable_array,
 }
 
 PropertyDataType Linear::dValue(VariableArray const& /*variable_array*/,
-                                Variable const primary_variable,
+                                Variable const variable,
                                 ParameterLib::SpatialPosition const& /*pos*/,
                                 double const /*t*/, double const /*dt*/) const
 {
-    auto const independent_variable =
-        std::find_if(independent_variables_.begin(),
-                     independent_variables_.end(),
-                     [&primary_variable](auto const& iv) -> bool
-                     { return iv.type == primary_variable; });
+    auto const independent_variable = std::find_if(
+        independent_variables_.begin(),
+        independent_variables_.end(),
+        [&variable](auto const& iv) -> bool { return iv.type == variable; });
 
     return independent_variable != independent_variables_.end()
                ? std::get<double>(value_) *
diff --git a/MaterialLib/MPL/Properties/Linear.h b/MaterialLib/MPL/Properties/Linear.h
index 484a9d1d45fa5fa2c54feafb7e8951721a1390bb..44765b88a6802941ed55e0166e6dfb490096637d 100644
--- a/MaterialLib/MPL/Properties/Linear.h
+++ b/MaterialLib/MPL/Properties/Linear.h
@@ -44,7 +44,7 @@ public:
     /// This method will compute the derivative of a property with respect to
     /// the given primary variable.
     PropertyDataType dValue(VariableArray const& variable_array,
-                            Variable const primary_variable,
+                            Variable const variable,
                             ParameterLib::SpatialPosition const& /*pos*/,
                             double const /*t*/,
                             double const /*dt*/) const override;
diff --git a/MaterialLib/MPL/Properties/OrthotropicEmbeddedFracturePermeability.cpp b/MaterialLib/MPL/Properties/OrthotropicEmbeddedFracturePermeability.cpp
index 29c46798ff5da8eb262ac5f783ca0c7bdd7d7b58..8031058036444677f8a40de60988ca3ae642b45e 100644
--- a/MaterialLib/MPL/Properties/OrthotropicEmbeddedFracturePermeability.cpp
+++ b/MaterialLib/MPL/Properties/OrthotropicEmbeddedFracturePermeability.cpp
@@ -87,11 +87,11 @@ OrthotropicEmbeddedFracturePermeability<DisplacementDim>::value(
 template <int DisplacementDim>
 PropertyDataType
 OrthotropicEmbeddedFracturePermeability<DisplacementDim>::dValue(
-    VariableArray const& variable_array, Variable const primary_variable,
+    VariableArray const& variable_array, Variable const variable,
     ParameterLib::SpatialPosition const& pos, double const t,
     double const /*dt*/) const
 {
-    if (primary_variable != Variable::mechanical_strain)
+    if (variable != Variable::mechanical_strain)
     {
         OGS_FATAL(
             "OrthotropicEmbeddedFracturePermeability::dValue is implemented "
diff --git a/MaterialLib/MPL/Properties/OrthotropicEmbeddedFracturePermeability.h b/MaterialLib/MPL/Properties/OrthotropicEmbeddedFracturePermeability.h
index 34ffadedf8c14d6a7b2fbb728531c3065f7dd40c..16fae69ddc8839812aa2ff1a0ba1cd3660b89044 100644
--- a/MaterialLib/MPL/Properties/OrthotropicEmbeddedFracturePermeability.h
+++ b/MaterialLib/MPL/Properties/OrthotropicEmbeddedFracturePermeability.h
@@ -87,7 +87,7 @@ public:
                            ParameterLib::SpatialPosition const& pos,
                            double const t, double const dt) const override;
     PropertyDataType dValue(VariableArray const& variable_array,
-                            Variable const primary_variable,
+                            Variable const variable,
                             ParameterLib::SpatialPosition const& pos,
                             double const t, double const dt) const override;
 };
diff --git a/MaterialLib/MPL/Properties/Parameter.cpp b/MaterialLib/MPL/Properties/Parameter.cpp
index c097d9d197aa7892a2fb666287683049a744c7ef..85e65e178ca5705fb893a69206b2b2810d9aac0c 100644
--- a/MaterialLib/MPL/Properties/Parameter.cpp
+++ b/MaterialLib/MPL/Properties/Parameter.cpp
@@ -35,7 +35,7 @@ PropertyDataType Parameter::value(VariableArray const& /*variable_array*/,
 }
 
 PropertyDataType Parameter::dValue(VariableArray const& /*variable_array*/,
-                                   Variable const /*primary_variable*/,
+                                   Variable const /*variable*/,
                                    ParameterLib::SpatialPosition const& /*pos*/,
                                    double const /*t*/,
                                    double const /*dt*/) const
diff --git a/MaterialLib/MPL/Properties/Parameter.h b/MaterialLib/MPL/Properties/Parameter.h
index 077282ff59062cd4393c3351d05ccbc5129ab610..f1adaf5be7b8dff782cf087b533125ac7c3aacca 100644
--- a/MaterialLib/MPL/Properties/Parameter.h
+++ b/MaterialLib/MPL/Properties/Parameter.h
@@ -39,7 +39,7 @@ public:
     /// This method will compute the derivative of a property with respect to
     /// the given primary variable.
     PropertyDataType dValue(VariableArray const& variable_array,
-                            Variable const primary_variable,
+                            Variable const variable,
                             ParameterLib::SpatialPosition const& /*pos*/,
                             double const /*t*/,
                             double const /*dt*/) const override;
diff --git a/MaterialLib/MPL/Properties/PermeabilityOrthotropicPowerLaw.cpp b/MaterialLib/MPL/Properties/PermeabilityOrthotropicPowerLaw.cpp
index 5bfc924f87ccf32bb3255d0ce59bf8e83126ee55..9093af7c66ab45909ba374d6af8d5593ca6553e2 100644
--- a/MaterialLib/MPL/Properties/PermeabilityOrthotropicPowerLaw.cpp
+++ b/MaterialLib/MPL/Properties/PermeabilityOrthotropicPowerLaw.cpp
@@ -86,11 +86,11 @@ PropertyDataType PermeabilityOrthotropicPowerLaw<DisplacementDim>::value(
 }
 template <int DisplacementDim>
 PropertyDataType PermeabilityOrthotropicPowerLaw<DisplacementDim>::dValue(
-    VariableArray const& /*variable_array*/, Variable const primary_variable,
+    VariableArray const& /*variable_array*/, Variable const variable,
     ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
     double const /*dt*/) const
 {
-    if (primary_variable != Variable::total_strain)
+    if (variable != Variable::total_strain)
     {
         OGS_FATAL(
             "PermeabilityOrthotropicPowerLaw::dValue is implemented for "
diff --git a/MaterialLib/MPL/Properties/PorosityFromMassBalance.cpp b/MaterialLib/MPL/Properties/PorosityFromMassBalance.cpp
index 3c0196874d5906586ef7d96bb2a9670b03d35991..97a139d53ce4cc8ba31f90b83057bf08798bdc13 100644
--- a/MaterialLib/MPL/Properties/PorosityFromMassBalance.cpp
+++ b/MaterialLib/MPL/Properties/PorosityFromMassBalance.cpp
@@ -63,8 +63,7 @@ PropertyDataType PorosityFromMassBalance::value(
 }
 
 PropertyDataType PorosityFromMassBalance::dValue(
-    VariableArray const& /*variable_array*/,
-    Variable const /*primary_variable*/,
+    VariableArray const& /*variable_array*/, Variable const /*variable*/,
     ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
     double const /*dt*/) const
 {
diff --git a/MaterialLib/MPL/Properties/RelativePermeability/RelPermUdellNonwettingPhase.cpp b/MaterialLib/MPL/Properties/RelativePermeability/RelPermUdellNonwettingPhase.cpp
index 4a5f231b4e60b364b53dd32e189fe9784c172bcd..760b8d5aa68dd9774cf53550b572fc0755612be2 100644
--- a/MaterialLib/MPL/Properties/RelativePermeability/RelPermUdellNonwettingPhase.cpp
+++ b/MaterialLib/MPL/Properties/RelativePermeability/RelPermUdellNonwettingPhase.cpp
@@ -67,11 +67,11 @@ PropertyDataType RelPermUdellNonwettingPhase::value(
     return std::max(min_relative_permeability_, S_e_g * S_e_g * S_e_g);
 }
 PropertyDataType RelPermUdellNonwettingPhase::dValue(
-    VariableArray const& variable_array, Variable const primary_variable,
+    VariableArray const& variable_array, Variable const variable,
     ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
     double const /*dt*/) const
 {
-    if (primary_variable != Variable::liquid_saturation)
+    if (variable != Variable::liquid_saturation)
     {
         OGS_FATAL(
             "RelPermUdellNonwettingPhase::dValue is implemented for "
diff --git a/MaterialLib/MPL/Properties/RelativePermeability/RelPermUdellNonwettingPhase.h b/MaterialLib/MPL/Properties/RelativePermeability/RelPermUdellNonwettingPhase.h
index f7df53cef145af649a53bfcc02be667583bba642..f49ec4c2e6aa012b6d22df4a5851b239f568f38e 100644
--- a/MaterialLib/MPL/Properties/RelativePermeability/RelPermUdellNonwettingPhase.h
+++ b/MaterialLib/MPL/Properties/RelativePermeability/RelPermUdellNonwettingPhase.h
@@ -66,7 +66,7 @@ public:
                            ParameterLib::SpatialPosition const& pos,
                            double const t, double const dt) const override;
     PropertyDataType dValue(VariableArray const& variable_array,
-                            Variable const primary_variable,
+                            Variable const variable,
                             ParameterLib::SpatialPosition const& pos,
                             double const t, double const dt) const override;
 };
diff --git a/MaterialLib/MPL/Properties/RelativePermeability/RelPermVanGenuchten.cpp b/MaterialLib/MPL/Properties/RelativePermeability/RelPermVanGenuchten.cpp
index eaaf1e248ebe9cf9110ca2b7efb28ca714019887..beee8a916fe4eb822b020427876f6069b8f0abd8 100644
--- a/MaterialLib/MPL/Properties/RelativePermeability/RelPermVanGenuchten.cpp
+++ b/MaterialLib/MPL/Properties/RelativePermeability/RelPermVanGenuchten.cpp
@@ -54,11 +54,11 @@ PropertyDataType RelPermVanGenuchten::value(
 }
 
 PropertyDataType RelPermVanGenuchten::dValue(
-    VariableArray const& variable_array, Variable const primary_variable,
+    VariableArray const& variable_array, Variable const variable,
     ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
     double const /*dt*/) const
 {
-    if (primary_variable != Variable::liquid_saturation)
+    if (variable != Variable::liquid_saturation)
     {
         OGS_FATAL(
             "RelativePermeabilityVanGenuchten::dValue is implemented for "
diff --git a/MaterialLib/MPL/Properties/SaturationDependentSwelling.cpp b/MaterialLib/MPL/Properties/SaturationDependentSwelling.cpp
index fbeb1d60a4229054890bbc8d5f8aff6c2875b8c5..68d8db3d8ff30319b986faa0140d10d8f5d887e8 100644
--- a/MaterialLib/MPL/Properties/SaturationDependentSwelling.cpp
+++ b/MaterialLib/MPL/Properties/SaturationDependentSwelling.cpp
@@ -103,11 +103,11 @@ PropertyDataType SaturationDependentSwelling::value(
 
 PropertyDataType SaturationDependentSwelling::dValue(
     VariableArray const& variable_array,
-    VariableArray const& variable_array_prev, Variable const primary_variable,
+    VariableArray const& variable_array_prev, Variable const variable,
     ParameterLib::SpatialPosition const& pos, double const /*t*/,
     double const /*dt*/) const
 {
-    if (primary_variable != Variable::liquid_saturation)
+    if (variable != Variable::liquid_saturation)
     {
         OGS_FATAL(
             "SaturationDependentSwelling::dValue is implemented for "
diff --git a/MaterialLib/MPL/Properties/SpecificHeatCapacityWithLatentHeat.cpp b/MaterialLib/MPL/Properties/SpecificHeatCapacityWithLatentHeat.cpp
index ddd51ffd6b8e69f726def36a30f0cedbd090c8f2..17900c67cd4a6f45dc809216f85c2eb3f13ac072 100644
--- a/MaterialLib/MPL/Properties/SpecificHeatCapacityWithLatentHeat.cpp
+++ b/MaterialLib/MPL/Properties/SpecificHeatCapacityWithLatentHeat.cpp
@@ -36,7 +36,7 @@ void SpecificHeatCapacityWithLatentHeat::setProperties(
     std::vector<std::unique_ptr<Phase>> const& phases)
 {
     // run over phases, identify them and get properties
-    for (auto& phase : phases)
+    for (auto const& phase : phases)
     {
         if (phase == nullptr)
         {
@@ -44,7 +44,7 @@ void SpecificHeatCapacityWithLatentHeat::setProperties(
                 "One of the required phases (AqueousLiquid/FrozenLiquid/Solid) "
                 "does not exist!");
         }
-        std::string phase_name = phase->name;
+        std::string const& phase_name = phase->name;
 
         auto const& density_property =
             phase->property(MaterialPropertyLib::PropertyType::density);
diff --git a/MaterialLib/MPL/Properties/TransportPorosityFromMassBalance.cpp b/MaterialLib/MPL/Properties/TransportPorosityFromMassBalance.cpp
index 93938219847613278590d21b289ac67e6f882e04..8a2573353865682060d6a86c95c083ca0448db46 100644
--- a/MaterialLib/MPL/Properties/TransportPorosityFromMassBalance.cpp
+++ b/MaterialLib/MPL/Properties/TransportPorosityFromMassBalance.cpp
@@ -65,8 +65,7 @@ PropertyDataType TransportPorosityFromMassBalance::value(
 }
 
 PropertyDataType TransportPorosityFromMassBalance::dValue(
-    VariableArray const& /*variable_array*/,
-    Variable const /*primary_variable*/,
+    VariableArray const& /*variable_array*/, Variable const /*variable*/,
     ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
     double const /*dt*/) const
 {
diff --git a/MaterialLib/MPL/Properties/VolumeFractionAverage.cpp b/MaterialLib/MPL/Properties/VolumeFractionAverage.cpp
index 5a6225a632000e2d0c497bc0e6002cbc35eaa764..f75dd26477f4b077e2bc9a85f90765ff51ac7669 100644
--- a/MaterialLib/MPL/Properties/VolumeFractionAverage.cpp
+++ b/MaterialLib/MPL/Properties/VolumeFractionAverage.cpp
@@ -40,7 +40,7 @@ void VolumeFractionAverage::setProperties(
     std::vector<std::unique_ptr<Phase>> const& phases)
 {
     // run over phases, identify them and get properties
-    for (auto& phase : phases)
+    for (auto const& phase : phases)
     {
         if (phase == nullptr)
         {
@@ -48,7 +48,7 @@ void VolumeFractionAverage::setProperties(
                 "One of the required phases (AqueousLiquid/FrozenLiquid/Solid) "
                 "does not exist!");
         }
-        std::string phase_name = phase->name;
+        std::string const& phase_name = phase->name;
 
         if (!phase->hasProperty(prop_type_))
         {
diff --git a/MeshLib/IO/XDMF/HdfWriter.cpp b/MeshLib/IO/XDMF/HdfWriter.cpp
index c4bb383630fb2acb85902e4a644113be9d2b6f31..6e5c1b8cdf67edfa7955d45ae2be3f4669a7b755 100644
--- a/MeshLib/IO/XDMF/HdfWriter.cpp
+++ b/MeshLib/IO/XDMF/HdfWriter.cpp
@@ -202,7 +202,6 @@ namespace MeshLib::IO
 struct HdfWriter::HdfMesh final
 {
     hid_t const group;
-    std::string const name;
     std::map<std::string, hid_t> const datasets;
     std::vector<HdfData> const variable_attributes;
 };
@@ -257,7 +256,7 @@ HdfWriter::HdfWriter(std::vector<MeshHdfData> meshes,
         }
 
         _hdf_meshes.push_back(std::make_unique<HdfMesh>(
-            HdfMesh{group, mesh.name, datasets, mesh.variable_attributes}));
+            HdfMesh{group, datasets, mesh.variable_attributes}));
     }
 }
 
diff --git a/NumLib/Exceptions.h b/NumLib/Exceptions.h
index b333a77e02754e36c1da14ec5c8d6e6ad2b38ab7..cb10f8ea7f20d95d2b40fb259811f17bd8d7b8e3 100644
--- a/NumLib/Exceptions.h
+++ b/NumLib/Exceptions.h
@@ -17,7 +17,7 @@ namespace NumLib
 {
 struct AssemblyException : public std::runtime_error
 {
-    AssemblyException(std::string const& reason)
+    explicit AssemblyException(std::string const& reason)
         : std::runtime_error{"Error in process' assembly: " + reason} {};
 };
 }  // namespace NumLib
diff --git a/NumLib/ODESolver/NonlinearSolver.cpp b/NumLib/ODESolver/NonlinearSolver.cpp
index ea7b9da1692390f7eccd6367dd9ae0eaf9f76e6b..93ca4a375f14ad707f409f97760913d1fef07bde 100644
--- a/NumLib/ODESolver/NonlinearSolver.cpp
+++ b/NumLib/ODESolver/NonlinearSolver.cpp
@@ -123,8 +123,8 @@ NonlinearSolverStatus NonlinearSolver<NonlinearSolverTag::Picard>::solve(
         if (!sys.isLinear() && _convergence_criterion->hasResidualCheck())
         {
             GlobalVector res;
-            LinAlg::matMult(A, x_new_process, res);       // res = A * x_new
-            LinAlg::axpy(res, -1.0, rhs);                 // res -= rhs
+            LinAlg::matMult(A, x_new_process, res);  // res = A * x_new
+            LinAlg::axpy(res, -1.0, rhs);            // res -= rhs
             _convergence_criterion->checkResidual(res);
         }
 
diff --git a/ProcessLib/BoundaryConditionAndSourceTerm/Python/BHEInflowPythonBoundaryConditionModule.cpp b/ProcessLib/BoundaryConditionAndSourceTerm/Python/BHEInflowPythonBoundaryConditionModule.cpp
index 0adae93753e6f92156298e723e014fbbc6438e3a..9cb70a7da4e05d82ec2cbc2624d82b1efbb6309e 100644
--- a/ProcessLib/BoundaryConditionAndSourceTerm/Python/BHEInflowPythonBoundaryConditionModule.cpp
+++ b/ProcessLib/BoundaryConditionAndSourceTerm/Python/BHEInflowPythonBoundaryConditionModule.cpp
@@ -49,7 +49,8 @@ public:
                           tespySolver, t, Tin_val, Tout_val);
     }
 
-    std::tuple<std::vector<double>, std::vector<double>> serverCommunicationPreTimestep(
+    std::tuple<std::vector<double>, std::vector<double>>
+    serverCommunicationPreTimestep(
         double const t, double const dt, std::vector<double> const& Tin_val,
         std::vector<double> const& Tout_val,
         std::vector<double> const& flowrate) const override
@@ -60,14 +61,15 @@ public:
             serverCommunicationPreTimestep, t, dt, Tin_val, Tout_val, flowrate);
     }
 
-    void serverCommunicationPostTimestep(double const t, double const dt,
-                             std::vector<double> const& Tin_val,
-                             std::vector<double> const& Tout_val,
-                             std::vector<double> const& flowrate) const override
+    void serverCommunicationPostTimestep(
+        double const t, double const dt, std::vector<double> const& Tin_val,
+        std::vector<double> const& Tout_val,
+        std::vector<double> const& flowrate) const override
     {
-        PYBIND11_OVERLOAD(
-            void, BHEInflowPythonBoundaryConditionPythonSideInterface,
-            serverCommunicationPostTimestep, t, dt, Tin_val, Tout_val, flowrate);
+        PYBIND11_OVERLOAD(void,
+                          BHEInflowPythonBoundaryConditionPythonSideInterface,
+                          serverCommunicationPostTimestep, t, dt, Tin_val,
+                          Tout_val, flowrate);
     }
 };
 
diff --git a/ProcessLib/ForwardDifferencesJacobianAssembler.h b/ProcessLib/ForwardDifferencesJacobianAssembler.h
index 826be6ada9c5349bb3f365d61c296f6d79d74818..69679112faab1e07847a2b80e9f2512856e7f110 100644
--- a/ProcessLib/ForwardDifferencesJacobianAssembler.h
+++ b/ProcessLib/ForwardDifferencesJacobianAssembler.h
@@ -45,8 +45,8 @@ public:
     //! by component.
     void assembleWithJacobian(LocalAssemblerInterface& local_assembler,
                               double const t, double const dt,
-                              std::vector<double> const& local_x,
-                              std::vector<double> const& local_xdot,
+                              std::vector<double> const& local_x_data,
+                              std::vector<double> const& local_xdot_data,
                               std::vector<double>& local_M_data,
                               std::vector<double>& local_K_data,
                               std::vector<double>& local_b_data,
diff --git a/ProcessLib/HeatTransportBHE/BHE/BHE_1U.h b/ProcessLib/HeatTransportBHE/BHE/BHE_1U.h
index 6a0dce99b12efd75b4393e767af6e585f0f45cad..5e38eb0ead9efe01746dc9d43961b1d9e6ee6725 100644
--- a/ProcessLib/HeatTransportBHE/BHE/BHE_1U.h
+++ b/ProcessLib/HeatTransportBHE/BHE/BHE_1U.h
@@ -167,9 +167,6 @@ private:
     /// 1) Diersch (2013) FEFLOW book on page 958, M.3, or
     /// 2) Diersch (2011) Comp & Geosci 37:1122-1135, Eq. 90-97.
     std::array<double, number_of_unknowns> _thermal_resistances;
-
-    /// Flow velocity inside the pipes. Depends on the flow_rate.
-    double _flow_velocity;
 };
 }  // namespace BHE
 }  // namespace HeatTransportBHE
diff --git a/ProcessLib/HeatTransportBHE/BHE/BHE_2U.h b/ProcessLib/HeatTransportBHE/BHE/BHE_2U.h
index c313b767021d11d2f6160a0b2f20259c7b87a569..cf43667bc1846f000268a3a87753859c13da665d 100644
--- a/ProcessLib/HeatTransportBHE/BHE/BHE_2U.h
+++ b/ProcessLib/HeatTransportBHE/BHE/BHE_2U.h
@@ -230,9 +230,6 @@ private:
     /// 1) Diersch (2013) FEFLOW book on page 958, M.3, or
     /// 2) Diersch (2011) Comp & Geosci 37:1122-1135, Eq. 90-97.
     std::array<double, number_of_unknowns> _thermal_resistances;
-
-    /// Flow velocity inside the pipes. Depends on the flow_rate.
-    double _flow_velocity;
 };
 }  // namespace BHE
 }  // namespace HeatTransportBHE
diff --git a/ProcessLib/HeatTransportBHE/BHE/CreateFlowAndTemperatureControl.cpp b/ProcessLib/HeatTransportBHE/BHE/CreateFlowAndTemperatureControl.cpp
index b2718c31d13e35fd5fb4ad47627dab6d2c46e619..813cad12ff787f4f2075094b69389cd475b57f06 100644
--- a/ProcessLib/HeatTransportBHE/BHE/CreateFlowAndTemperatureControl.cpp
+++ b/ProcessLib/HeatTransportBHE/BHE/CreateFlowAndTemperatureControl.cpp
@@ -119,8 +119,8 @@ FlowAndTemperatureControl createFlowAndTemperatureControl(
             "Required flow rate curve not found.");
 
         return PowerCurveFlowCurve{power_curve, flow_rate_curve,
-                                      refrigerant.specific_heat_capacity,
-                                      refrigerant.density};
+                                   refrigerant.specific_heat_capacity,
+                                   refrigerant.density};
     }
 
     if (type == "BuildingPowerCurveConstantFlow")
diff --git a/ProcessLib/HeatTransportBHE/HeatTransportBHEProcess.cpp b/ProcessLib/HeatTransportBHE/HeatTransportBHEProcess.cpp
index e8ed0470a34fe0db829046d70f9d97c2d1363f0c..d0c98f49afd78a9de707868c2c516c5e8801560b 100644
--- a/ProcessLib/HeatTransportBHE/HeatTransportBHEProcess.cpp
+++ b/ProcessLib/HeatTransportBHE/HeatTransportBHEProcess.cpp
@@ -287,8 +287,8 @@ void HeatTransportBHEProcess::preTimestepConcreteProcess(
 
     // Transfer T_out to server_Communication and get back T_in and flowrate
     auto const server_communication_result =
-        _process_data.py_bc_object->serverCommunicationPreTimestep(t, dt, Tin_value,
-                                                        Tout_value, flowrate);
+        _process_data.py_bc_object->serverCommunicationPreTimestep(
+            t, dt, Tin_value, Tout_value, flowrate);
     if (!_process_data.py_bc_object
              ->isOverriddenServerCommunicationPreTimestep())
     {
@@ -335,8 +335,8 @@ void HeatTransportBHEProcess::postTimestepConcreteProcess(
     }
 
     // Transfer T_out to server_Communication
-    _process_data.py_bc_object->serverCommunicationPostTimestep(t, dt, Tin_value,
-                                                         Tout_value, flowrate);
+    _process_data.py_bc_object->serverCommunicationPostTimestep(
+        t, dt, Tin_value, Tout_value, flowrate);
     if (!_process_data.py_bc_object
              ->isOverriddenServerCommunicationPostTimestep())
     {
diff --git a/ProcessLib/Output/Output.cpp b/ProcessLib/Output/Output.cpp
index 2378b4257fe2a83118e44ea9b7e9761ea42ffdef..6cfb0e88a01b2de2cb33a63e5537dc75bbe5c910 100644
--- a/ProcessLib/Output/Output.cpp
+++ b/ProcessLib/Output/Output.cpp
@@ -58,7 +58,6 @@ void addBulkMeshNodePropertyToSubMesh(MeshLib::Mesh const& bulk_mesh,
                    { return bulk_mesh_property[id]; });
 }
 
-
 bool Output::isOutputStep(int timestep, double const t) const
 {
     auto const fixed_output_time = std::lower_bound(
diff --git a/Tests/MaterialLib/TestSpecificHeatCapacityWithLatentHeat.cpp b/Tests/MaterialLib/TestSpecificHeatCapacityWithLatentHeat.cpp
index cc77141eb1caf2583149b73893ff21e69bbe4de3..c37f0f7c7d607e789514eb09a282389bad2f103e 100644
--- a/Tests/MaterialLib/TestSpecificHeatCapacityWithLatentHeat.cpp
+++ b/Tests/MaterialLib/TestSpecificHeatCapacityWithLatentHeat.cpp
@@ -19,20 +19,21 @@
 struct IceWaterRockParameters
 {
     double const k = 1;
-    double const T_c = 273.15;  // K
-    double const rho_I = 900;   // kg/m³
-    double const rho_W = 1000;  // kg/m³
-    double const rho_R = 3000;  // kg/m³
-    double const kap_I = 2.37;  // W/m/K
-    double const kap_W = 0.54;  // W/m/K
-    double const kap_R = 3.00;  // W/m/K
-    double const cp_I = 2052;   // J/kg/K
-    double const cp_W = 4186;   // J/kg/K
-    double const cp_R = 2500;   // J/kg/K
-    double const L_IW = 334.e3;    // J/kg
+    double const T_c = 273.15;   // K
+    double const rho_I = 900;    // kg/m³
+    double const rho_W = 1000;   // kg/m³
+    double const rho_R = 3000;   // kg/m³
+    double const kap_I = 2.37;   // W/m/K
+    double const kap_W = 0.54;   // W/m/K
+    double const kap_R = 3.00;   // W/m/K
+    double const cp_I = 2052;    // J/kg/K
+    double const cp_W = 4186;    // J/kg/K
+    double const cp_R = 2500;    // J/kg/K
+    double const L_IW = 334.e3;  // J/kg
 };
 
-std::unique_ptr<MaterialPropertyLib::Medium> createMyMedium(double L_IW, double porosity)
+std::unique_ptr<MaterialPropertyLib::Medium> createMyMedium(double L_IW,
+                                                            double porosity)
 {
     std::stringstream prj;
     IceWaterRockParameters water_ice_rock;
@@ -161,7 +162,8 @@ TEST(MaterialPropertyLib, SpecificHeatCapacityWithLatentHeat_trivial)
                 MaterialPropertyLib::PropertyType::specific_heat_capacity)
             .template value<double>(vars, pos, t, dt);
     auto const Capp_expected = Cvol_mix / rho_mix;
-    auto const relativeError = std::fabs((Capp_expected - Capp) / Capp_expected);
+    auto const relativeError =
+        std::fabs((Capp_expected - Capp) / Capp_expected);
 
     ASSERT_LE(relativeError, 1e-10)
         << "for expected apparent heat capacity " << Capp_expected
@@ -182,8 +184,9 @@ TEST(MaterialPropertyLib, SpecificHeatCapacityWithLatentHeat_atTc)
 
     // at the critical temperature the frozen and the liquid phase have same
     // volume fractions of 0.5
-    auto const rho_mix = phi * 0.5 * (water_ice_rock.rho_I + water_ice_rock.rho_W)
-                       + (1 - phi) * water_ice_rock.rho_R;
+    auto const rho_mix =
+        phi * 0.5 * (water_ice_rock.rho_I + water_ice_rock.rho_W) +
+        (1 - phi) * water_ice_rock.rho_R;
 
     auto const Cvol_mix =
         phi * 0.5 *
@@ -197,9 +200,11 @@ TEST(MaterialPropertyLib, SpecificHeatCapacityWithLatentHeat_atTc)
     auto const Capp =
         medium->property(MPL::PropertyType::specific_heat_capacity)
             .template value<double>(vars, pos, t, dt);
-    auto const Capp_expected =
-        (Cvol_mix + water_ice_rock.L_IW * rho_mix * phi * water_ice_rock.k / 4) / rho_mix;
-    auto const relativeError = std::fabs((Capp_expected - Capp) / Capp_expected);
+    auto const Capp_expected = (Cvol_mix + water_ice_rock.L_IW * rho_mix * phi *
+                                               water_ice_rock.k / 4) /
+                               rho_mix;
+    auto const relativeError =
+        std::fabs((Capp_expected - Capp) / Capp_expected);
 
     ASSERT_LE(relativeError, 1e-10)
         << "for expected apparent heat capacity " << Capp_expected
@@ -225,7 +230,8 @@ TEST(MaterialPropertyLib, SpecificHeatCapacityWithLatentHeat_belowTc)
         medium->property(MPL::PropertyType::specific_heat_capacity)
             .template value<double>(vars, pos, t, dt);
     auto const Capp_expected = water_ice_rock.cp_I;
-    auto const relativeError = std::fabs((Capp_expected - Capp) / Capp_expected);
+    auto const relativeError =
+        std::fabs((Capp_expected - Capp) / Capp_expected);
 
     ASSERT_LE(relativeError, 1e-10)
         << "for expected apparent heat capacity " << Capp_expected
@@ -251,7 +257,8 @@ TEST(MaterialPropertyLib, SpecificHeatCapacityWithLatentHeat_aboveTc)
         medium->property(MPL::PropertyType::specific_heat_capacity)
             .template value<double>(vars, pos, t, dt);
     auto const Capp_expected = water_ice_rock.cp_W;
-    auto const relativeError = std::fabs((Capp_expected - Capp) / Capp_expected);
+    auto const relativeError =
+        std::fabs((Capp_expected - Capp) / Capp_expected);
 
     ASSERT_LE(relativeError, 1e-10)
         << "for expected apparent heat capacity " << Capp_expected
diff --git a/Tests/MaterialLib/TestTemperatureDependentFraction.cpp b/Tests/MaterialLib/TestTemperatureDependentFraction.cpp
index 3c58e610b93f850e70d57cb1e048a475c9ecdb62..848b468c9966e385b816221bab6f05b36beb6857 100644
--- a/Tests/MaterialLib/TestTemperatureDependentFraction.cpp
+++ b/Tests/MaterialLib/TestTemperatureDependentFraction.cpp
@@ -13,19 +13,18 @@
 
 #include <sstream>
 /* Keep for debugging
-#include <iostream>
 #include <fstream>
+#include <iostream>
 */
 
 #include "MaterialLib/MPL/Properties/TemperatureDependentFraction.h"
-
 #include "TestMPL.h"
 #include "Tests/TestTools.h"
 
 struct ParameterSet
 {
     double const k = 1;
-    double const T_c = 273.15; // K
+    double const T_c = 273.15;  // K
 };
 
 std::unique_ptr<MaterialPropertyLib::Medium> createMyMedium()
@@ -118,13 +117,15 @@ TEST(MaterialPropertyLib, TemperatureDependentFraction_value_atTc)
 
     vars.temperature = water_ice.T_c;
 
-    auto const phi = medium->property(MaterialPropertyLib::PropertyType::porosity).template
-                                value<double>(vars, pos, time, dt);
+    auto const phi =
+        medium->property(MaterialPropertyLib::PropertyType::porosity)
+            .template value<double>(vars, pos, time, dt);
 
     // calculate the temperature dependent (e.g. frozen) part of the pore space
     auto const pfr_expected = phi * 0.5;
-    auto const pfr = medium->property(MaterialPropertyLib::PropertyType::volume_fraction).template
-                                value<double>(vars, pos, time, dt);
+    auto const pfr =
+        medium->property(MaterialPropertyLib::PropertyType::volume_fraction)
+            .template value<double>(vars, pos, time, dt);
 
     auto const relativeError = std::fabs((pfr_expected - pfr) / pfr_expected);
 
@@ -147,17 +148,20 @@ TEST(MaterialPropertyLib, TemperatureDependentFraction_dValue_atTc)
 
     vars.temperature = water_ice.T_c;
 
-    auto const phi = medium->property(MaterialPropertyLib::PropertyType::porosity).template
-                                value<double>(vars, pos, time, dt);
+    auto const phi =
+        medium->property(MaterialPropertyLib::PropertyType::porosity)
+            .template value<double>(vars, pos, time, dt);
 
-    // calculate temperature-derivative of temperature dependent (e.g. frozen) volume fraction
-    auto const dpfr_dT_expected = - phi * water_ice.k * 0.25;
+    // calculate temperature-derivative of temperature dependent (e.g. frozen)
+    // volume fraction
+    auto const dpfr_dT_expected = -phi * water_ice.k * 0.25;
     auto const dpfr_dT =
         medium->property(MaterialPropertyLib::PropertyType::volume_fraction)
             .template dValue<double>(vars, MPL::Variable::temperature, pos,
                                      time, dt);
 
-    auto const relativeError = std::fabs((dpfr_dT_expected - dpfr_dT) / dpfr_dT_expected);
+    auto const relativeError =
+        std::fabs((dpfr_dT_expected - dpfr_dT) / dpfr_dT_expected);
 
     ASSERT_LE(relativeError, 1e-10)
         << "for expected apparent heat capacity " << dpfr_dT_expected
diff --git a/Tests/MaterialLib/TestVolumeFractionAverage.cpp b/Tests/MaterialLib/TestVolumeFractionAverage.cpp
index c4472527719a6fd167212f2b566fad60ea12617e..37fac9b2248eb64a8ab753ef974a377dceae5586 100644
--- a/Tests/MaterialLib/TestVolumeFractionAverage.cpp
+++ b/Tests/MaterialLib/TestVolumeFractionAverage.cpp
@@ -10,6 +10,7 @@
  */
 
 #include <gtest/gtest.h>
+
 #include <sstream>
 
 #include "MaterialLib/MPL/Utils/FormEigenTensor.h"
@@ -98,8 +99,9 @@ TEST(MaterialPropertyLib, VolumeFractionAverage_Density)
     MaterialPropertyLib::VariableArray vars;
     vars.temperature = water_ice_rock.T_c;
 
-    auto const& phi = medium->property(MaterialPropertyLib::PropertyType::porosity)
-                     .template value<double>(vars, pos, time, dt);
+    auto const& phi =
+        medium->property(MaterialPropertyLib::PropertyType::porosity)
+            .template value<double>(vars, pos, time, dt);
 
     auto rho_m = medium->property(MaterialPropertyLib::PropertyType::density)
                      .template value<double>(vars, pos, time, dt);
@@ -212,11 +214,14 @@ TEST(MaterialPropertyLib, VolumeFractionAverage_ThermalConductivity)
     MaterialPropertyLib::VariableArray vars;
     vars.temperature = water_ice_rock.T_c;
 
-    auto const& phi = medium->property(MaterialPropertyLib::PropertyType::porosity)
-                     .template value<double>(vars, pos, time, dt);
+    auto const& phi =
+        medium->property(MaterialPropertyLib::PropertyType::porosity)
+            .template value<double>(vars, pos, time, dt);
 
-    auto kap_m = medium->property(MaterialPropertyLib::PropertyType::thermal_conductivity)
-                     .template value<double>(vars, pos, time, dt);
+    auto kap_m =
+        medium
+            ->property(MaterialPropertyLib::PropertyType::thermal_conductivity)
+            .template value<double>(vars, pos, time, dt);
 
     auto const kap_expected =
         (1 - phi) * water_ice_rock.kap_R +
diff --git a/web/content/docs/devguide/advanced/vscode-devcontainer/index.md b/web/content/docs/devguide/advanced/vscode-devcontainer/index.md
index bcda58a8b7fdd366efcc6665b8911bb320812713..7759631889bd657255f751c80fc0f42f60725e0f 100644
--- a/web/content/docs/devguide/advanced/vscode-devcontainer/index.md
+++ b/web/content/docs/devguide/advanced/vscode-devcontainer/index.md
@@ -9,7 +9,7 @@ weight = 1061
     parent = "advanced"
 +++
 
-[Visual Studio Code](https://code.visualstudio.com/) is a powerful text editor which can be expanded to a full featured integrated development environment (IDE) with plugins. With the  [Visual Studio Code Remote - Containers](https://code.visualstudio.com/docs/remote/containers) extension you can use prebuilt Docker container as the runtime environment for your code development. This page serves as an alterntive to the [Getting Started]({{< relref "docs/devguide/getting-started/introduction.md" >}})-section. The following features make this a nice development environment:
+[Visual Studio Code](https://code.visualstudio.com/) is a powerful text editor which can be expanded to a full featured integrated development environment (IDE) with plugins. With the  [Visual Studio Code Remote - Containers](https://code.visualstudio.com/docs/remote/containers) extension you can use prebuilt Docker container as the runtime environment for your code development. This page serves as an alternative to the [Getting Started]({{< relref "docs/devguide/getting-started/introduction.md" >}})-section. The following features make this a nice development environment:
 
 - All ogs prerequisites (except of MPI / PETSc support, may come later) already setup.
 - Code editing with auto-completion.
diff --git a/web/content/docs/devguide/development-workflows/web-docs/index.md b/web/content/docs/devguide/development-workflows/web-docs/index.md
index 5bd02194928f23d72c69eed63cd68a7cef8180c5..babfa964cb856a193cb814fc614024cb0b855398 100644
--- a/web/content/docs/devguide/development-workflows/web-docs/index.md
+++ b/web/content/docs/devguide/development-workflows/web-docs/index.md
@@ -67,7 +67,7 @@ This page will be available at the URL `/docs/my-post/` and the content of the p
 
 Page meta data is given in frontmatter.
 
-- `weight`: Navigation is handled automatically by the folder structure. Use the `weight`-paramter in the frontmatter to specify the order of pages in ascending order (top `->` down).
+- `weight`: Navigation is handled automatically by the folder structure. Use the `weight`-parameter in the frontmatter to specify the order of pages in ascending order (top `->` down).
 - `image`: Specify an image in the page bundle used for the gallery view.
 
 ### Write a page
diff --git a/ProcessLib/CentralDifferencesJacobianAssembler.h b/ProcessLib/CentralDifferencesJacobianAssembler.h
index 6c522ebfde2ced1043541e394f7d3cedc643897e..8c7e6e06eb053513c2417996a37d34323b031825 100644
--- a/ProcessLib/CentralDifferencesJacobianAssembler.h
+++ b/ProcessLib/CentralDifferencesJacobianAssembler.h
@@ -46,14 +46,14 @@ public:
     //! is called several times and the Jacobian is built from finite
     //! differences.
     //! The number of calls of the assemble() method is \f$2N+1\f$ if \f$N\f$ is
     //! the size of \c local_x.
     //!
     //! \attention It is assumed that the local vectors and matrices are ordered
     //! by component.
     void assembleWithJacobian(LocalAssemblerInterface& local_assembler,
                               double const t, double const dt,
-                              std::vector<double> const& local_x,
-                              std::vector<double> const& local_xdot,
+                              std::vector<double> const& local_x_data,
+                              std::vector<double> const& local_xdot_data,
                               std::vector<double>& local_M_data,
                               std::vector<double>& local_K_data,
                               std::vector<double>& local_b_data,
@@ -46,14 +46,14 @@ public:
     //! differences.
     //! The number of calls of the assemble() method is \f$2N+1\f$ if \f$N\f$ is
-    //! the size of \c local_x.
+    //! the size of \c local_x_data.
     //!
     //! \attention It is assumed that the local vectors and matrices are ordered